pub struct FixedArray<T, TAllocator>where
TAllocator: Allocator,{ /* private fields */ }Expand description
A fixed-capacity array. This type is similar to DynamicArray,
except its capacity is fixed at runtime, instead of compile time. Internally it keeps a pointer
to heap allocated data. That heap allocated data is never resized during the array’s lifetime.
This type does require an allocator. But if the size exceeds capacity it simply returns an error.
Implementations
Sourceimpl<T, TAllocator> FixedArray<T, TAllocator>where
TAllocator: Allocator,
impl<T, TAllocator> FixedArray<T, TAllocator>where
TAllocator: Allocator,
Sourcepub fn with_capacity_and_allocator(
capacity: Length,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new FixedArray with capacity and allocator.
This allocates memory only when capacity > 0.
Errors
For details see ArrayError.
Sourcepub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
pub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new FixedArray with capacity and the default allocator.
This allocates memory only when capacity > 0.
Errors
For details see ArrayError.
Sourcepub fn with_factory<Factory: FnMut(usize) -> T>(
size: Length,
factory: Factory,
) -> Result<Self, ArrayError>where
TAllocator: Default,
pub fn with_factory<Factory: FnMut(usize) -> T>(
size: Length,
factory: Factory,
) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new FixedArray with a given size, generated through a given factory.
This allocates memory only when size > 0.
Errors
For details see ArrayError.
Sourcepub fn with_factory_and_allocator<Factory: FnMut(usize) -> T>(
size: Length,
factory: Factory,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub fn with_factory_and_allocator<Factory: FnMut(usize) -> T>( size: Length, factory: Factory, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new FixedArray with a given size, generated through a given factory,
with a custom allocator. This allocates memory only when size > 0.
Errors
For details see ArrayError.
Sourcepub unsafe fn with_size_uninitialized(size: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
pub unsafe fn with_size_uninitialized(size: Length) -> Result<Self, ArrayError>where
TAllocator: Default,
Creates a new FixedArray with a given size, but uninitialized.
Safety
The underlying array is uninitialized and reading the data is UB, unless initialized first.
Errors
For details see ArrayError.
Sourcepub unsafe fn with_size_and_allocator_uninitialized(
size: Length,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub unsafe fn with_size_and_allocator_uninitialized( size: Length, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new FixedArray with a given size and allocator, but uninitialized.
Safety
The underlying array is uninitialized and reading the data is UB, unless initialized first.
Errors
For details see ArrayError.