pub struct InlineFixedArray<const TSIZE: usize, T: Sized> { /* private fields */ }Expand description
A fixed-capacity array. This type is similar to DynamicArray,
except its capacity is fixed at compile time, and doesn’t change at runtime. The “Inline” prefix
indicates that the data is stored inside the struct itself, meaning its size depends on TSIZE.
In particular this type does not require an allocator.
Implementations
Sourceimpl<const TSIZE: usize, T: Sized> InlineFixedArray<TSIZE, T>
impl<const TSIZE: usize, T: Sized> InlineFixedArray<TSIZE, T>
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new, empty InlineFixedArray.
Panics
This function will panic if the TSIZE is invalid, i.e.
when either TSIZE is 0 or exceeds [Length::MAX_LENGTH].
Sourcepub const fn length(&self) -> Length
pub const fn length(&self) -> Length
Returns the length of the InlineFixedArray.
pub const fn is_empty(&self) -> bool
Sourcepub const fn capacity(&self) -> Length
pub const fn capacity(&self) -> Length
Returns the capacity of the InlineFixedArray. This is TSIZE
as [Length].
Sourcepub const fn as_slice_const(&self) -> &[T]
pub const fn as_slice_const(&self) -> &[T]
Returns the InlineFixedArray as immutable slice.
Sourcepub const fn as_slice_mut_const(&mut self) -> &mut [T]
pub const fn as_slice_mut_const(&mut self) -> &mut [T]
Returns the InlineFixedArray as mutable slice.